/*  JAL - Cross-platform Java Application Loader for Motorola mobile phones
 *  Copyright (C) 2006  Andrew Ivanov <andrew@softmile.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public Licensse as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#include "main_wnd.h"
#include "device_connection.h"

DeviceConnection *gConn = NULL;

void _info_cb ( const char *info )
{
	if ( gConn ) {
		gConn->info_cb( info );
	}
}

void _progress_cb ( int pos )
{
	if ( pos == -1 )
	{
		pos = 0;
	}
	if ( gConn ) {
		gConn->progress_cb( pos );
	}
}

DeviceConnection::DeviceConnection( QObject *parent )
	: QThread( parent )
{
	gConn = this;
	m_debug = false;
}


void DeviceConnection::init( QString sPort, int iBaudID, int speed, QString sFileName )
{
	m_sPort = sPort;
	m_BaudRate = dwBaudRates[iBaudID];
	m_speed = speed;
	m_sFileName = sFileName;
	
}


void DeviceConnection::run( )
{
	jal_set_info_callback( _info_cb );
	jal_set_progress_callback( _progress_cb );
	if ( m_debug ) {
		jal_debug( m_sPort.toLocal8Bit(), m_BaudRate );
	} else {
		jal_set_speed( m_speed );
		jal_upload_file( m_sPort.toLocal8Bit(), m_BaudRate, m_sFileName.toLocal8Bit() );
	}
}

void DeviceConnection::info_cb( QString sInfo )
{
	emit info( sInfo );
}

void DeviceConnection::progress_cb( int pos )
{
	emit progress( pos );
}

void DeviceConnection::debug( )
{
	m_debug = true;
	start();
}

void DeviceConnection::upload()
{
	m_debug = false;
	start();
}

bool DeviceConnection::isDebug()
{
	return m_debug;
}
