/*  JAL - Cross-platform Java Application Loader for Motorola mobile phones
 *  Copyright (C) 2006  Andrew Ivanov <andrew@softmile.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public Licensse as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#include <QSettings>
#include "settings.h"
#ifdef WIN32
#include "select_port.h"
#else
#include <QFileDialog>
#endif

Settings::Settings( QWidget * parent, Qt::WFlags f )
    : QDialog( parent, f )
{
    ui.setupUi(this);
	QSettings settings;
	ui.lineEditPort->setText( settings.value( "port" ).toString( ) );
	ui.comboBoxBaudRate->setCurrentIndex( settings.value( "baud", 6 ).toInt( ) );
	ui.speedSlider->setValue( settings.value( "speed", 50 ).toInt( ) );
#ifndef WIN32
	ui.toolButtonPort->setVisible( false );
	ui.lineEditPort->setReadOnly( false );
#endif	
}

void Settings::on_toolButtonPort_clicked()
{
#ifdef WIN32
	SelectPort dlg(this);
	if ( dlg.exec() == QDialog::Accepted ) {
		ui.lineEditPort->setText( dlg.getPort() );
	}
#endif
}

void Settings::accept()
{
	QSettings settings;
	settings.setValue( "port", ui.lineEditPort->text() );
	settings.setValue( "baud", ui.comboBoxBaudRate->currentIndex() );
	settings.setValue( "speed", ui.speedSlider->value() );
	QDialog::accept();
}
